Installation of pywbem
======================

To install the latest released version of pywbem into your active Python
environment:

      $ pip install pywbem

This will also install any prerequisite Python packages.

Since version 1.0.0, pywbem has no more OS-level prerequisite packages.

For more details and alternative ways to install, see the
[Installation section](https://pywbem.readthedocs.io/en/stable/intro.html#installation)
in the pywbem documentation.
